@@ -1,4 +1,5 @@
 import copy
+import json
 import uuid
 import arrow
 from datetime import datetime
@@ -32,8 +33,20 @@ class InternalBaseModel(Base):
     create_time = Column(DateTime, default=datetime.now)
     update_time = Column(DateTime, default=datetime.now, onupdate=datetime.now)
 
-    def model_dump(self) -> Dict[str, Any]:
-        return {column.name: getattr(self, column.name) for column in self.__table__.columns}
+    def model_dump(self, mode: str = "json", exclude: set = None) -> Dict[str, Any]:
+        """將 SQLAlchemy 模型轉換為字典"""
+        exclude = exclude or set()
+        result = {}
+
+        for column in self.__table__.columns:
+            if column.name not in exclude:
+                value = getattr(self, column.name)
+                if mode == "json" and isinstance(value, datetime):
+                    result[column.name] = value.isoformat()
+                else:
+                    result[column.name] = value
+
+        return result
 
     def model_copy(self):
         return copy.deepcopy(self.model_dump())
@@ -68,7 +81,7 @@ class InternalBaseModel(Base):
             history_model.operator_id = current_operator.id
             history_model.operator_name = current_operator.name
             history_model.operator_type = current_operator.type
-            history_model.operate = operate.model_dump(mode="json")
+            history_model.operate = json.dumps(operate.model_dump())
 
             db.add(history_model)
             await db.flush()
@@ -104,7 +117,7 @@ class InternalBaseModel(Base):
             history_model.operator_id = current_operator.id
             history_model.operator_name = current_operator.name
             history_model.operator_type = current_operator.type
-            history_model.operate = operate.model_dump(mode="json")
+            history_model.operate = json.dumps(operate.model_dump())
 
             db.add(history_model)
             await db.flush()
